<?php

	/**
	 * Translated by Chih-Hsin Lee [chlee@femh.org.tw]
	 * $Id: chinese-tr.php,v 1.15 2007/04/24 11:42:07 soranzo Exp $
	 *
	 *
	 */

	// Language and character set
	$lang['applang'] = '餤]big5^';
	$lang['appcharset'] = 'big5';
	$lang['applocale'] = 'zh_TW';
	$lang['appdbencoding'] = 'EUC_TW';
	$lang['applangdir'] = 'ltr';
	
	// Welcome  
	$lang['strintro'] = 'wϥphpPgAdmin.';
	$lang['strppahome'] = 'phpPgAdmin';
	$lang['strpgsqlhome'] = 'PostgreSQL';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL  ()';
	$lang['strreportbug'] = 'q{';
	$lang['strviewfaq'] = '`ݻP';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = 'nJ';
	$lang['strloginfailed'] = 'nJ';
	$lang['strlogindisallowed'] = 'AڵnJ';
	$lang['strserver'] = 'A';
	$lang['strlogout'] = 'hX';
	$lang['strowner'] = 'ݤH';
	$lang['straction'] = '\';
	$lang['stractions'] = '\';
	$lang['strname'] = 'Wr';
	$lang['strdefinition'] = 'wq';
	$lang['strproperties'] = 'ݩ';
	$lang['strbrowse'] = 's';
	$lang['strdrop'] = 'R';
	$lang['strdropped'] = 'wR';
	$lang['strnull'] = '\ŭ';
	$lang['strnotnull'] = '\ŭ';
	$lang['strprev'] = '< W@B';
	$lang['strnext'] = 'U@B >';
	$lang['strfirst'] = '<< Ĥ@B';
	$lang['strlast'] = '̫@B >>';
	$lang['strfailed'] = '';
	$lang['strcreate'] = 'إ';
	$lang['strcreated'] = 'wإ';
	$lang['strcomment'] = '';
	$lang['strlength'] = '';
	$lang['strdefault'] = 'w]';
	$lang['stralter'] = 'ק';
	$lang['strok'] = 'Tw';
	$lang['strcancel'] = '';
	$lang['strsave'] = 'xs';
	$lang['strreset'] = ']';
	$lang['strinsert'] = 'J';
	$lang['strselect'] = '';
	$lang['strdelete'] = 'R';
	$lang['strupdate'] = 's';
	$lang['strreferences'] = 'Ѧ';
	$lang['stryes'] = 'O';
	$lang['strno'] = '_';
	$lang['strtrue'] = 'u';
	$lang['strfalse'] = '';
	$lang['stredit'] = 'ק';
	$lang['strcolumns'] = 'Ʀ';
	$lang['strrows'] = 'ƦC';
	$lang['strrowsaff'] = 'ƦCvTC';
	$lang['strobjects'] = '';
	$lang['strexample'] = 'ҦpG';
	$lang['strback'] = '^';
	$lang['strqueryresults'] = 'dߵG';
	$lang['strshow'] = '';
	$lang['strempty'] = '';
	$lang['strlanguage'] = 'y';
	$lang['strencoding'] = 'sX';
	$lang['strvalue'] = '';
	$lang['strunique'] = 'W@';
	$lang['strprimary'] = 'D';
	$lang['strexport'] = 'ץX';
	$lang['strimport'] = 'פJ';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = '}l';
	$lang['stradmin'] = '޲z';
	$lang['strvacuum'] = 'M';
	$lang['stranalyze'] = 'R';
	$lang['strclusterindex'] = 'O';
	$lang['strclustered'] = 'O?';
	$lang['strreindex'] = 'د';
	$lang['strrun'] = '';
	$lang['stradd'] = '[J';
	$lang['strevent'] = 'ƥ';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = 'Do Instead';
	$lang['strwhen'] = '';
	$lang['strformat'] = '榡';
	$lang['strdata'] = '';
	$lang['strconfirm'] = 'T{';
	$lang['strexpression'] = 'ܦ';
	$lang['strellipsis'] = '...';
	$lang['strexpand'] = 'i}';
	$lang['strcollapse'] = 'P|';
	$lang['strexplain'] = 'ĩ';
	$lang['strexplainanalyze'] = 'ĩR';
	$lang['strfind'] = 'M';
	$lang['stroptions'] = 'ﶵ';
	$lang['strrefresh'] = 'sz';
	$lang['strdownload'] = 'U';
	$lang['strdownloadgzipped'] = 'HgzipYU';
	$lang['strinfo'] = 'T'; 
    $lang['stroids'] = 'OIDs'; 
    $lang['stradvanced'] = 'i';
	$lang['strvariables'] = 'ܼ';
	$lang['strprocess'] = '{';
	$lang['strprocesses'] = '{';
	$lang['strsetting'] = ']w';
	$lang['streditsql'] = 'sSQL';
	$lang['strruntime'] = '`@ɶ: %s ms';
	$lang['strpaginate'] = 'ܵG';
	$lang['struploadscript'] = 'άOWǤ@SQLO:';
	$lang['strstarttime'] = '}lɶ';
	$lang['strfile'] = 'ɮ';
	$lang['strfileimported'] = 'ɮפwפJC';

	// Error handling
	$lang['strbadconfig'] = 'z config.inc.php LġCЧQ config.inc.php-dist إ߱z config.inc.php ɡC';
	$lang['strnotloaded'] = 'z PHP ҥw˥ݪƮw䴩C';
	$lang['strbadschema'] = 'wFLĪҦ (schema)C';
	$lang['strbadencoding'] = 'ƮwLk]wΤݪsX覡C';
	$lang['strsqlerror'] = 'SQL ~G';
	$lang['strinstatement'] = '󳯭zG';
	$lang['strinvalidparam'] = 'LĪ script ܼơC';
	$lang['strnodata'] = '䤣ƦCC';
	$lang['strnoobjects'] = '䤣󪫥C';
	$lang['strrownotunique'] = 'ƦCLWSѧOC';
	$lang['strnoreportsdb'] = 'z|طsƮwAаѾ\INSTALLɻC';
	$lang['strnouploads'] = 'Wɮץ\wΡC';
	$lang['strimporterror'] = 'פJ~C';
	$lang['strimporterrorline'] = 'פJ~oͩ %s C';

	// Tables
	$lang['strtable'] = 'ƪ';
	$lang['strtables'] = 'ƪ';
	$lang['strshowalltables'] = 'ܩҦƪ';
	$lang['strnotables'] = '䤣즹ƪC';
	$lang['strnotable'] = '䤣ƪC';
	$lang['strcreatetable'] = 'إ߷sƪ';
	$lang['strtablename'] = 'ƪW';
	$lang['strtableneedsname'] = 'zݬzƪRWC';
	$lang['strtableneedsfield'] = 'zܤw@C';
	$lang['strtableneedscols'] = 'ƪݭn@wƥتƦC';
	$lang['strtablecreated'] = '\إ߸ƪC';
	$lang['strtablecreatedbad'] = 'إ߸ƪ@~ѡC';
	$lang['strconfdroptable'] = 'zTwnRƪ "%s"?';
	$lang['strtabledropped'] = '\RƪC';
	$lang['strtabledroppedbad'] = 'Rƪ@~ѡC';
	$lang['strconfemptytable'] = 'zTwnMŸƪ "%s"?';
	$lang['strtableemptied'] = '\MŸƪC';
	$lang['strtableemptiedbad'] = 'MŸƪ@~ѡC';
	$lang['strinsertrow'] = 'JƦ';
	$lang['strrowinserted'] = '\JƦC';
	$lang['strrowinsertedbad'] = 'JƦ@~ѡC';
	$lang['streditrow'] = 'קƦ';
	$lang['strrowupdated'] = '\sƦC';
	$lang['strrowupdatedbad'] = 'sƦ@~ѡC';
	$lang['strdeleterow'] = 'RƦ';
	$lang['strconfdeleterow'] = 'zTwnRǸƦ?';
	$lang['strrowdeleted'] = '\RƦC';
	$lang['strrowdeletedbad'] = 'ƦR@~ѡC';
	$lang['strsaveandrepeat'] = 'xsí';
	$lang['strfield'] = '';
	$lang['strfields'] = '';
	$lang['strnumfields'] = 'ƥ';
	$lang['strfieldneedsname'] = 'zݬzRWC';
	$lang['strselectallfields'] = 'ܩҦ';
	$lang['strselectneedscol'] = 'ܤܤ@ƦCC';
	$lang['strselectunary'] = 'ର@BlwƭȡC';
	$lang['straltercolumn'] = 'קƦC';
	$lang['strcolumnaltered'] = '\קƦCC';
	$lang['strcolumnalteredbad'] = 'קƦC@~ѡC';
	$lang['strconfdropcolumn'] = 'zTwnRƦC "%s" ƪ "%s"?';
	$lang['strcolumndropped'] = '\RƦCC';
	$lang['strcolumndroppedbad'] = 'RƦC@~ѡC';
	$lang['straddcolumn'] = '[Js';
	$lang['strcolumnadded'] = '\[JC';
	$lang['strcolumnaddedbad'] = '[J@~ѡC';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = 'ƪwקC';
	$lang['strtablealteredbad'] = 'ƪק@~ѡC';
	$lang['strdataonly'] = 'uܸ'; 
    $lang['strstructureonly'] = 'uc'; 
    $lang['strstructureanddata'] = 'ƩMc'; 
	$lang['strtabbed'] = 'Tabbed';
	$lang['strauto'] = '۰';

	// Users
	$lang['struser'] = 'Τ';
	$lang['strusers'] = 'Τ';
	$lang['strusername'] = 'ΤW';
	$lang['strpassword'] = 'KX';
	$lang['strsuper'] = 'WťΤ?';
	$lang['strcreatedb'] = '\إ߸Ʈw?';
	$lang['strexpires'] = '';
	$lang['strsessiondefaults'] = 'w]Session';
	$lang['strnousers'] = '䤣즹ΤC';
	$lang['struserupdated'] = '\sΤC';
	$lang['struserupdatedbad'] = 'sΤ@~ѡC';
	$lang['strshowallusers'] = 'ܩҦΤ';
	$lang['strcreateuser'] = 'إ߷sΤ';
	$lang['struserneedsname'] = 'ЬΤR';
	$lang['strusercreated'] = '\إ߷sΤC';
	$lang['strusercreatedbad'] = 'إ߷sΤ@~ѡC';
	$lang['strconfdropuser'] = 'zTwnRΤ "%s"?';
	$lang['struserdropped'] = 'ΤwRC';
	$lang['struserdroppedbad'] = 'RΤ@~ѡC';
	$lang['straccount'] = 'b';
	$lang['strchangepassword'] = 'KX';
	$lang['strpasswordchanged'] = '\KXC';
	$lang['strpasswordchangedbad'] = 'KX@~ѡC';
	$lang['strpasswordshort'] = 'KXӵuC';
	$lang['strpasswordconfirm'] = 'ҿJձKXPC';
	
	// Groups
	$lang['strgroup'] = 's';
	$lang['strgroups'] = 's';
	$lang['strnogroup'] = '䤣즹sաC';
	$lang['strnogroups'] = '䤣sաC';
	$lang['strcreategroup'] = 'إ߷ss';
	$lang['strshowallgroups'] = 'ܩҦs';
	$lang['strgroupneedsname'] = 'zݬzsթRWC';
	$lang['strgroupcreated'] = '\إ߸sաC';
	$lang['strgroupcreatedbad'] = 'sիإߧ@~ѡC';	
	$lang['strconfdropgroup'] = 'zTwRs "%s"?';
	$lang['strgroupdropped'] = '\RsաC';
	$lang['strgroupdroppedbad'] = 'Rsէ@~ѡC';
	$lang['strmembers'] = 'Τ';
	$lang['straddmember'] = 'sWΤ';
	$lang['strmemberadded'] = 'w[JΤC';
	$lang['strmemberaddedbad'] = 'sWΤᥢѡC';
	$lang['strdropmember'] = 'RΤ';
	$lang['strconfdropmember'] = 'zTwnRΤ "%s" qs "%s"?';
	$lang['strmemberdropped'] = 'ΤwRC';
	$lang['strmemberdroppedbad'] = 'RΤ@~ѡC';
	
	// Privilges
	$lang['strprivilege'] = 'Sv';
	$lang['strprivileges'] = 'Sv';
	$lang['strnoprivileges'] = 'Ӫ󦳹w]ݤJSvC';
	$lang['strgrant'] = 'ᤩ';
	$lang['strrevoke'] = 'M^';
	$lang['strgranted'] = '\SvC';
	$lang['strgrantfailed'] = 'Sv@~ѡC';
	$lang['strgrantbad'] = 'z@WϥΪ̩θsիwܤ֤@ӯSvC';
	$lang['stralterprivs'] = 'Sv';
	$lang['strgrantor'] = 'v';
	$lang['strasterisk'] = '*';
	
	// Databases
	$lang['strdatabase'] = 'Ʈw';
	$lang['strdatabases'] = 'Ʈw';
	$lang['strshowalldatabases'] = 'ܩҦƮw';
	$lang['strnodatabase'] = '䤣즹ƮwC';
	$lang['strnodatabases'] = '䤣ƮwC';
	$lang['strcreatedatabase'] = 'إ߷sƮw';
	$lang['strdatabasename'] = 'ƮwW';
	$lang['strdatabaseneedsname'] = 'zݬzƮwRWC';
	$lang['strdatabasecreated'] = '\إ߸ƮwC';
	$lang['strdatabasecreatedbad'] = 'إ߸Ʈw@~ѡC';	
	$lang['strconfdropdatabase'] = 'zTwnRƮw "%s"?';
	$lang['strdatabasedropped'] = '\RƮwC';
	$lang['strdatabasedroppedbad'] = 'RƮw@~ѡC';
	$lang['strentersql'] = 'UJҭn檺 SQL zG';
	$lang['strsqlexecuted'] = '\ SQL C';
	$lang['strvacuumgood'] = 'Mŧ@~C';
	$lang['strvacuumbad'] = 'Mŧ@~ѡC';
	$lang['stranalyzegood'] = 'R@~C';
	$lang['stranalyzebad'] = 'R@~.';
	$lang['strreindexgood'] = 'ޭاC';
	$lang['strreindexbad'] = 'ޭإѡC';
	$lang['strfull'] = '';
	$lang['strfreeze'] = 'ᵲ';
	$lang['strforce'] = 'j';
	
	// Views
	$lang['strview'] = '';
	$lang['strviews'] = '';
	$lang['strshowallviews'] = 'ܩҦ';
	$lang['strnoview'] = '䤣즹C';
	$lang['strnoviews'] = '䤣C';
	$lang['strcreateview'] = 'إ߷s';
	$lang['strviewname'] = 'W';
	$lang['strviewneedsname'] = 'zݬzRWC';
	$lang['strviewneedsdef'] = 'zwqAC';
	$lang['strviewneedsfields'] = 'пܭn[JC';
	$lang['strviewcreated'] = '\إ߷sC';
	$lang['strviewcreatedbad'] = 'إ߷s@~';
	$lang['strconfdropview'] = 'zTwnR "%s"?';
	$lang['strviewdropped'] = '\RC';
	$lang['strviewdroppedbad'] = 'R@~ѡC';
	$lang['strviewupdated'] = '\sC';
	$lang['strviewupdatedbad'] = 's@~ѡC';
	$lang['strviewlink'] = 's';
	$lang['strviewconditions'] = 'B~';
	$lang['strcreateviewwiz'] = 'ϥεF';

	// Sequences
	$lang['strsequence'] = 'ǦC';
	$lang['strsequences'] = 'ǦC';
	$lang['strshowallsequences'] = 'ܩҦǦC';
	$lang['strnosequence'] = '䤣즹ǦCC';
	$lang['strnosequences'] = '䤣ǦCC';
	$lang['strcreatesequence'] = 'إ߷sǦC';
	$lang['strlastvalue'] = '';
	$lang['strincrementby'] = 'Wq ([/) ';	
	$lang['strstartvalue'] = 'ҩl';
	$lang['strmaxvalue'] = '̤j';
	$lang['strminvalue'] = '̤֭';
	$lang['strcachevalue'] = '֨';
	$lang['strlogcount'] = 'nƶq';
	$lang['striscycled'] = '`?';
	$lang['strsequenceneedsname'] = 'zݬzǦCRWC';
	$lang['strsequencecreated'] = '\إ߷sǦCC';
	$lang['strsequencecreatedbad'] = 'إ߷sǦC@~ѡC'; 
	$lang['strconfdropsequence'] = 'zTwnRǦC "%s"?';
	$lang['strsequencedropped'] = '\RǦCC';
	$lang['strsequencedroppedbad'] = 'RǦC@~ѡC';
	$lang['strsequencereset'] = 'w]ǦCC'; 
    $lang['strsequenceresetbad'] = ']ǦCѡC'; 
    
	// Indexes
	$lang['strindex'] = '';
	$lang['strindexes'] = '';
	$lang['strindexname'] = 'ަW';
	$lang['strshowallindexes'] = 'ܩҦ';
	$lang['strnoindex'] = '䤣즹ޡC';
	$lang['strnoindexes'] = '䤣ޡC';
	$lang['strcreateindex'] = 'إ߷s';
	$lang['strtabname'] = '˯W';
	$lang['strcolumnname'] = 'ƦCW';
	$lang['strindexneedsname'] = 'zݬzީRWC';
	$lang['strindexneedscols'] = '@wưݪƦCC';
	$lang['strindexcreated'] = '\إ߷s';
	$lang['strindexcreatedbad'] = 'إ߯ާ@~ѡC';
	$lang['strconfdropindex'] = 'zTwnR "%s"?';
	$lang['strindexdropped'] = '\RޡC';
	$lang['strindexdroppedbad'] = 'Rާ@~ѡC';
	$lang['strkeyname'] = 'W';
	$lang['struniquekey'] = 'W@';
	$lang['strprimarykey'] = 'D';
 	$lang['strindextype'] = '';
	$lang['strtablecolumnlist'] = 'ƪҧtƦC';
	$lang['strindexcolumnlist'] = 'ީҧtƦC';
    $lang['strconfcluster'] = 'zTwnO "%s"?'; 
    $lang['strclusteredgood'] = 'OC'; 
    $lang['strclusteredbad'] = 'OѡC'; 

	// Rules
	$lang['strrules'] = 'Wh';
	$lang['strrule'] = 'Wh';
	$lang['strshowallrules'] = 'ܩҦWh';
	$lang['strnorule'] = '䤣즹WhC';
	$lang['strnorules'] = '䤣WhC';
	$lang['strcreaterule'] = 'إ߷sWh';
	$lang['strrulename'] = 'WhW';
	$lang['strruleneedsname'] = 'zݬzWhRWC';
	$lang['strrulecreated'] = '\إ߷sWhC';
	$lang['strrulecreatedbad'] = 'إ߷sWh@~ѡC';
	$lang['strconfdroprule'] = 'zTwnR "%s"  "%s"?';
	$lang['strruledropped'] = '\RWhC';
	$lang['strruledroppedbad'] = 'RWh@~ѡC';

	// Constraints
	$lang['strconstraints'] = '';
	$lang['strshowallconstraints'] = 'ܩҦ';
	$lang['strnoconstraints'] = '䤣즹C';
	$lang['strcreateconstraint'] = 'إ߷s';
	$lang['strconstraintcreated'] = '\إ߷sC';
	$lang['strconstraintcreatedbad'] = 'sج@~ѡC';
	$lang['strconfdropconstraint'] = 'zTwnR "%s"  "%s"?';
	$lang['strconstraintdropped'] = '\RC';
	$lang['strconstraintdroppedbad'] = 'R@~ѡC';
	$lang['straddcheck'] = '[Jsd (check)';
	$lang['strcheckneedsdefinition'] = 'zݩwqzd (check)C';
	$lang['strcheckadded'] = '\[Jsd (check)C';
	$lang['strcheckaddedbad'] = '[Jsd (check) @~ѡC';
	$lang['straddpk'] = '[JD';
	$lang['strpkneedscols'] = 'Dܤ]t@ӸƦC';
	$lang['strpkadded'] = '\[JDC';
	$lang['strpkaddedbad'] = '[JD@@~ѡC';
	$lang['stradduniq'] = '[JW@';
	$lang['struniqneedscols'] = 'W@ܤ]t@ӸƦC';
	$lang['struniqadded'] = '\[JW@C';
	$lang['struniqaddedbad'] = '[JW@@~ѡC';
	$lang['straddfk'] = '[J~';
	$lang['strfkneedscols'] = '~ܤ]t@ӸƦC';
	$lang['strfkneedstarget'] = '~ݰѷӥؼиƪC';
	$lang['strfkadded'] = '\[J~C';
	$lang['strfkaddedbad'] = '[J~@~ѡC';
	$lang['strfktarget'] = 'ؼиƪ';
	$lang['strfkcolumnlist'] = 'ҧtƦ';
	$lang['strondelete'] = 'R';
	$lang['stronupdate'] = '';	

	// Functions
	$lang['strfunction'] = '';
	$lang['strfunctions'] = '';
	$lang['strshowallfunctions'] = 'ܩҦ';
	$lang['strnofunction'] = '䤣즹ơC';
	$lang['strnofunctions'] = '䤣ơC';
	$lang['strcreatefunction'] = 'إ߷s';
	$lang['strfunctionname'] = 'ƦW';
	$lang['strreturns'] = '^';
	$lang['strarguments'] = 'Ѽ';
	$lang['strproglanguage'] = '{y';
	$lang['strfunctionneedsname'] = 'zݬzƩRWC';
	$lang['strfunctionneedsdef'] = 'zwqzơC';
	$lang['strfunctioncreated'] = '\إ߷sơC';
	$lang['strfunctioncreatedbad'] = 'sبƧ@~ѡC';
	$lang['strconfdropfunction'] = 'zTwnR "%s"?';
	$lang['strfunctiondropped'] = '\RơC';
	$lang['strfunctiondroppedbad'] = 'RƧ@~ѡC';
	$lang['strfunctionupdated'] = '\ơC';
	$lang['strfunctionupdatedbad'] = 'Ƨ@~ѡC';

	// Triggers
	$lang['strtrigger'] = 'Ĳo';
	$lang['strtriggers'] = 'Ĳo';
	$lang['strshowalltriggers'] = 'ܩҦĲo';
	$lang['strnotrigger'] = '䤣즹ĲoC';
	$lang['strnotriggers'] = '䤣ĲoC';
	$lang['strcreatetrigger'] = 'إ߷sĲo';
	$lang['strtriggerneedsname'] = 'zݬzĲoRWC';
	$lang['strtriggerneedsfunc'] = 'zAĲow@ӨơC';
	$lang['strtriggercreated'] = '\إ߷sĲoC';
	$lang['strtriggercreatedbad'] = 'إĲo@~ѡC';
	$lang['strconfdroptrigger'] = 'zTwnRĲo "%s"  "%s"?';
	$lang['strtriggerdropped'] = '\RĲoC';
	$lang['strtriggerdroppedbad'] = 'RĲo@~ѡC';
	$lang['strtriggeraltered'] = 'ĲowקC';
	$lang['strtriggeralteredbad'] = 'קĲo@~ѡC';

	// Types
	$lang['strtype'] = '';
	$lang['strtypes'] = '';
	$lang['strshowalltypes'] = 'ܩҦ';
	$lang['strnotype'] = '䤣즹C';
	$lang['strnotypes'] = '䤣C';
	$lang['strcreatetype'] = 'إ߷s';
	$lang['strtypename'] = 'W';
	$lang['strinputfn'] = 'J';
	$lang['stroutputfn'] = 'X';
	$lang['strpassbyval'] = 'Hȶǰe?';
	$lang['stralignment'] = 'ƦC';
	$lang['strelement'] = '';
	$lang['strdelimiter'] = 'jŸ';
	$lang['strstorage'] = 'xs';
	$lang['strtypeneedsname'] = 'zݬzRWC';
	$lang['strtypeneedslen'] = 'zwzסC';
	$lang['strtypecreated'] = '\إ߷s';
	$lang['strtypecreatedbad'] = ' إ@~ѡC';
	$lang['strconfdroptype'] = 'zTwnR "%s"?';
	$lang['strtypedropped'] = '\RC';
	$lang['strtypedroppedbad'] = 'R@~ѡC';

	// Schemas
	$lang['strschema'] = 'Ҧ';
	$lang['strschemas'] = 'Ҧ';
	$lang['strshowallschemas'] = 'ܩҦҦ';
	$lang['strnoschema'] = '䤣즹Ҧ';
	$lang['strnoschemas'] = '䤣ҦC';
	$lang['strcreateschema'] = 'إ߷sҦ';
	$lang['strschemaname'] = 'ҦW';
	$lang['strschemaneedsname'] = 'zݬzҦRWC';
	$lang['strschemacreated'] = '\إ߷sҦC';
	$lang['strschemacreatedbad'] = 'إ߼Ҧ@~ѡC';
	$lang['strconfdropschema'] = 'zTwnRҦ "%s"?';
	$lang['strschemadropped'] = '\RҦC ';
	$lang['strschemadroppedbad'] = 'RҦ@~ѡC';
	$lang['strschemaaltered'] = '\קҦ';
	$lang['strschemaalteredbad'] = 'קҦѡC';
	
	// Reports
	$lang['strreport'] = '';
	$lang['strreports'] = '';
	$lang['strshowallreports'] = 'ܩҦ';
	$lang['strnoreports'] = '䤣즹C';
	$lang['strcreatereport'] = 'إ߷s';
	$lang['strreportdropped'] = '\RC';
	$lang['strreportdroppedbad'] = 'R@~ѡC';
	$lang['strconfdropreport'] = 'zTwnR "%s"?';
	$lang['strreportneedsname'] = 'zݬzRWC';
	$lang['strreportneedsdef'] = 'zݵz SQLC';
	$lang['strreportcreated'] = '\xsC';
	$lang['strreportcreatedbad'] = 'LkxsC';
	
	// Domains
	$lang['strdomain'] = '';
	$lang['strdomains'] = '';
	$lang['strshowalldomains'] = 'ܩҦ';
	$lang['strnodomains'] = '䤣C';
	$lang['strcreatedomain'] = 'sػ';
	$lang['strdomaindropped'] = 'wRC';
	$lang['strdomaindroppedbad'] = 'R@~ѡC';
	$lang['strconfdropdomain'] = 'zTwnR "%s"?';
	$lang['strdomainneedsname'] = 'zݬRWC';
	$lang['strdomaincreated'] = 'wإߡC';
	$lang['strdomaincreatedbad'] = 'sػ@~ѡC';	
	$lang['strdomainaltered'] = 'wקC';
	$lang['strdomainalteredbad'] = 'ק@~ѡC';
	
	// Operators
	$lang['stroperator'] = 'Bl';
	$lang['stroperators'] = 'Bl';
	$lang['strshowalloperators'] = 'ܩҦBls';
	$lang['strnooperator'] = '䤣BlC';
	$lang['strnooperators'] = '䤣BlC';
	$lang['strcreateoperator'] = 'sعBl';
	$lang['strleftarg'] = '޼ƫA';
	$lang['strrightarg'] = 'k޼ƫA';
    $lang['strcommutator'] = 'ഫ'; 
    $lang['strnegator'] = '_w'; 
    $lang['strrestrict'] = ''; 
    $lang['strjoin'] = 'X'; 
    $lang['strhashes'] = 'Hashes'; 
    $lang['strmerges'] = 'X'; 
    $lang['strleftsort'] = 'Ƨ'; 
    $lang['strrightsort'] = 'kƧ'; 
    $lang['strlessthan'] = 'p'; 
    $lang['strgreaterthan'] = 'j'; 
	$lang['stroperatorneedsname'] = 'zݬzBlRWC';
	$lang['stroperatorcreated'] = 'Blwإ';
	$lang['stroperatorcreatedbad'] = 'Blsا@~ѡC';
	$lang['strconfdropoperator'] = 'zTwnRBl "%s"?';
	$lang['stroperatordropped'] = 'BlwRC';
	$lang['stroperatordroppedbad'] = 'BlRѡC';

	// Casts 
   $lang['strcasts'] = 'Oഫ'; 
   $lang['strnocasts'] = '䤣쫬OഫC'; 
   $lang['strsourcetype'] = 'lO'; 
   $lang['strtargettype'] = '᫬O'; 
   $lang['strimplicit'] = 't'; 
   $lang['strinassignment'] = ''; 
   $lang['strbinarycompat'] = '(G۲)'; 

   // Conversions 
   $lang['strconversions'] = 'ഫ'; 
   $lang['strnoconversions'] = '䤣ഫC'; 
   $lang['strsourceencoding'] = 'lsX'; 
   $lang['strtargetencoding'] = 'ؼнsX'; 

   // Languages 
   $lang['strlanguages'] = 'y'; 
   $lang['strnolanguages'] = '䤣yC'; 
   $lang['strtrusted'] = 'H'; 

   // Info 
   $lang['strnoinfo'] = 'LkoTC'; 
   $lang['strreferringtables'] = 'ѷӸƪ'; 
   $lang['strparenttables'] = 'ƪ'; 
   $lang['strchildtables'] = 'lƪ'; 

   // Aggregates
   $lang['straggregates'] = '`';
   $lang['strnoaggregates'] = '䤣`C';
   $lang['stralltypes'] = '()';	
	
   // Operator Classes
   $lang['stropclasses'] = 'BlO';
   $lang['strnoopclasses'] = '䤣BOC';
   $lang['straccessmethod'] = 'ڵs';
   
   // Stats and performance
   $lang['strrowperf'] = 'ƦĲv';
   $lang['strioperf'] = 'I/OĲv';
   $lang['stridxrowperf'] = 'ަĲv';
   $lang['stridxioperf'] = 'I/OĲv';
   $lang['strpercent'] = '%';
   $lang['strsequential'] = '`';
   $lang['strscan'] = 'y';
   $lang['strread'] = 'Ū';
   $lang['strfetch'] = 'Fetch';
   $lang['strheap'] = 'Heap';
   $lang['strtoast'] = 'TOAST';
   $lang['strtoastindex'] = 'TOAST';
   $lang['strcache'] = '֨';
   $lang['strdisk'] = 'Ϻ';
   $lang['strrows2'] = 'Ʀ';
   
	// Miscellaneous
   $lang['strtopbar'] = '%s  %s:%s  zO "%s" , %s';
   $lang['strtimefmt'] = 'jS M, Y g:iA';
   $lang['strhelp'] = '';
	
?>
